@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# flake8: NOQA W605
 """Helper methods and mixins.
 
 libtmux.common
@@ -14,7 +14,7 @@ import sys
 from distutils.version import LooseVersion
 
 from . import exc
-from ._compat import console_to_str, str_from_console
+from ._compat import MutableMapping, console_to_str, str_from_console
 
 logger = logging.getLogger(__name__)
 
@@ -204,11 +204,7 @@ class tmux_cmd(object):
             self.process = subprocess.Popen(
                 cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE
             )
-            self.process.wait()
-            stdout = self.process.stdout.read()
-            self.process.stdout.close()
-            stderr = self.process.stderr.read()
-            self.process.stderr.close()
+            stdout, stderr = self.process.communicate()
             returncode = self.process.returncode
         except Exception as e:
             logger.error('Exception for %s: \n%s' % (subprocess.list2cmdline(cmd), e))
@@ -230,9 +226,9 @@ class tmux_cmd(object):
         logger.debug('self.stdout for %s: \n%s' % (' '.join(cmd), self.stdout))
 
 
-class TmuxMappingObject(collections.MutableMapping):
+class TmuxMappingObject(MutableMapping):
 
-    """Base: :py:class:`collections.MutableMapping`.
+    r"""Base: :py:class:`MutableMapping`.
 
     Convenience container. Base class for :class:`Pane`, :class:`Window`,
     :class:`Session` and :class:`Server`.
@@ -635,13 +631,16 @@ def session_check_name(session_name):
 def handle_option_error(error):
     """Raises exception if error in option command found.
 
-    Purpose: As of tmux 2.4, there are now 3 different types of option errors:
+    In tmux 3.0, show-option and show-window-otion return invalid option instead of
+    unknown option. See https://github.com/tmux/tmux/blob/3.0/cmd-show-options.c.
+
+    In tmux >2.4, there are 3 different types of option errors:
 
     - unknown option
     - invalid option
     - ambiguous option
 
-    Before 2.4, unknown option was the user.
+    In tmux <2.4, unknown option was the only option.
 
     All errors raised will have the base error of :exc:`exc.OptionError`. So to
     catch any option error, use ``except exc.OptionError``.
@@ -664,3 +663,16 @@ def handle_option_error(error):
         raise exc.AmbiguousOption(error)
     else:
         raise exc.OptionError(error)  # Raise generic option error
+
+
+def get_libtmux_version():
+    """Return libtmux version is a PEP386 compliant format.
+
+    Returns
+    -------
+    distutils.version.LooseVersion
+        libtmux version
+    """
+    from libtmux.__about__ import __version__
+
+    return LooseVersion(__version__)
