@@ -1,17 +1,13 @@
-# -*- coding: utf-8 -*-
 """Pythonization of the :term:`tmux(1)` session.
 
 libtmux.session
 ~~~~~~~~~~~~~~~
 
 """
-from __future__ import absolute_import, unicode_literals, with_statement
-
 import logging
 import os
 
 from . import exc, formats
-from ._compat import text_type
 from .common import (
     EnvironmentMixin,
     TmuxMappingObject,
@@ -27,7 +23,7 @@ logger = logging.getLogger(__name__)
 
 class Session(TmuxMappingObject, TmuxRelationalObject, EnvironmentMixin):
     """
-    A :term:`tmux(1)` :term:`session` [#]_.
+    A :term:`tmux(1)` :term:`Session` [session_manual]_.
 
     Holds :class:`Window` objects.
 
@@ -37,7 +33,7 @@ class Session(TmuxMappingObject, TmuxRelationalObject, EnvironmentMixin):
 
     References
     ----------
-    .. [#] tmux session. openbsd manpage for TMUX(1).
+    .. [session_manual] tmux session. openbsd manpage for TMUX(1).
            "When tmux is started it creates a new session with a single window
            and displays it on screen..."
 
@@ -96,7 +92,7 @@ class Session(TmuxMappingObject, TmuxRelationalObject, EnvironmentMixin):
             Renamed from ``.tmux`` to ``.cmd``.
         """
         # if -t is not set in any arg yet
-        if not any('-t' in text_type(x) for x in args):
+        if not any('-t' in str(x) for x in args):
             # insert -t immediately after 1st arg, as per tmux format
             new_args = [args[0]]
             new_args += ['-t', self.id]
@@ -357,7 +353,10 @@ class Session(TmuxMappingObject, TmuxRelationalObject, EnvironmentMixin):
             assure ``-l``, ``-n``, ``-p`` work.
         """
 
-        target = '-t%s' % target_window
+        # Note that we also provide the session ID here, since cmd()
+        # will not automatically add it as there is already a '-t'
+        # argument provided.
+        target = '-t%s:%s' % (self._session_id, target_window)
 
         proc = self.cmd('select-window', target)
 
